Uses of Class
com.cedarsoftware.util.FastReader.BufferSlice
Packages that use FastReader.BufferSlice
-
Uses of FastReader.BufferSlice in com.cedarsoftware.util
Methods in com.cedarsoftware.util with parameters of type FastReader.BufferSliceModifier and TypeMethodDescriptionintFastReader.readLineBorrowed(FastReader.BufferSlice slice) Borrow a complete line from the current internal buffer without copying.intFastReader.readUntilBorrowed(FastReader.BufferSlice slice, int maxLen, char delim1, char delim2) Borrow a contiguous slice from the internal buffer up to either delimiter.